searchData={"items":[{"type":"module","title":"Md","doc":"`Md` is a markup parser allowing fully customized syntax definition and\nunderstanding the wide range of [markdown](https://www.markdownguide.org/) out of the box.\n\nIt is stream-aware, extendable, flexible, blazingly fast, with callbacks and more.","ref":"Md.html"},{"type":"module","title":"Main Focus - Md","doc":"This library is not yet another markdown parser, rather it’s a highly configurable\nand extendable parser for any custom markdown-like markup. It has been created\nmostly to allow custom markdown syntax, like `^foo^` for superscript, or `⇓bar⇓`\nfor subscript. It also supports [custom parsers](https://hexdocs.pm/md/Md.Parser.html)\nfor anything that cannot be handled with generic parsers, inspired by markdown\n(something more complex than standard markdown provides.)\n\nThe library provides callbacks for all the default syntax handlers, as well as for\ncustom handlers, allowing the on-fly modification of what’s currently being processed.\n\n`Md` parses the incoming stream **once** and keeps the state, producing an AST\nof the input document. It has an ability to recover from errors collecting them.\n\nIt currently does not support (and I frankly doubt it ever will)\nlists with embedded quotes, and other contrived syntax. If one needs to perfectly\nparse the common markdown, `Md` is probably not the correct choice.\n\nBut if one wants to easily extend syntax almost without limits, `Md` might be good.","ref":"Md.html#module-main-focus"},{"type":"module","title":"Markup Handling - Md","doc":"There are several different syntax patterns recognizable by `Md`. Those are:\n\n- `custom` — the custom parser implementing `Md.Parser` behavious would be called\n- `attributes` — inplace attributes for all tags `\"{{foo:'bar'}}\"` → `\"<… foo='bar' …>\"`\n- `substitute` — simple substitution, like `\"<\"` → `\"&lt;\"`\n- `escape` — characters to be treated as is, not as a part of syntax\n- `comment` — characters to be treated as a comment, discarded in the output\n- `flush` — somewhat breaking a paragraph flow, like triple-dash\n- `magnet` — the markup for a single work following the patters, like `#tag`\n- `block` — the whole block of input treated distinguished, like triple-backtick\n- `shift` — the same as `block`, but the opening marker should precede each line\n  and `\"\\n\"` is treated as the closing marker\n- `pair` — the opening marker followed by closing marker, and a subsequent pair\n  of opening and closing, like `![name](#anchor)`; the second element might\n  be an internal shortcut to the deferred disclosure\n- `disclosure` — the disclosure of elements previously declared as `pair` with\n  `deferred` parameter provided\n- `paragraph` — a header, blockquote, or such, followed by a paragraph flow break\n- `list` — a list, like `- one\\n- two`\n- `tag` — allowed tags (e. g. ` 2 `)\n- `brace` — a most common markdown feature, like text decoration or such (e. g. `**bold**`)","ref":"Md.html#module-markup-handling"},{"type":"module","title":"Syntax description - Md","doc":"The syntax must be configured at compile time (because `parse/2` handlers are\ngenerated in compile time.) It is a map, having `settings` key\n\n```elixir\nsettings: %{\n  outer: :p,\n  span: :span,\n  empty_tags: ~w|img hr br|a\n}\n```\n\nand `key ⇒ list_of_tuples` key-values, providing a text markup representation\nand its handling rules. Here is the excerpt from the default parser for `brace`s\n\n```elixir\n  brace: %{\n    \"*\" => %{tag: :b},\n    \"_\" => %{tag: :i},\n    \"**\" => %{tag: :strong, attributes: %{class: \"nota-bene\"}},\n    \"__\" => %{tag: :em},\n    \"~\" => %{tag: :s},\n    \"~~\" => %{tag: :del},\n    \"`\" => %{tag: :code, mode: :raw, attributes: %{class: \"code-inline\"}}\n  }\n```\n\nFor more examples of what properties are allowed for each kind of handlers,\nsee the sources (ATM.)","ref":"Md.html#module-syntax-description"},{"type":"module","title":"Predefined parsers - Md","doc":"`Md` comes with a generic predefined parser `Md.Parser.Default`, which includes\nall the markup currently supported by `Md`.\n\nCustom parser definition would be usually based on `Md.Parser.Syntax.Void` syntax\nas shown below\n\n```elixir\ndefmodule MyParser do\n  use Md.Parser\n\n  alias Md.Parser.Syntax.Void\n\n  @default_syntax Map.put(Void.syntax(), :settings, Void.settings())\n  @syntax @default_syntax |> Map.merge(%{\n    comment: [{\"<!--\", %{closing: \"-->\"}}],\n    paragraph: [\n      {\"##\", %{tag: :h2}},\n      {\"###\", %{tag: :h3}},\n      {\">\", %{tag: :blockquote}}\n    ],\n    list:\n      [\n        {\"- \", %{tag: :li, outer: :ul}},\n        {\"+ \", %{tag: :li, outer: :ol}}\n      ]\n    brace: [\n      {\"*\", %{tag: :b}},\n      {\"_\", %{tag: :i}},\n      {\"~\", %{tag: :s}},\n      {\"`\", %{tag: :code, mode: :raw, attributes: %{class: \"code-inline\"}}}\n    ]\n  })\nend\n```\n\n`@syntax` module attribute must be declared, or DSL used as shown below\n(declarations), or an argument in a call to `use Md.Parser`.\nThe separate declarations will be collected and merged.\n\n```elixir\ndefmodule MyDSLParser do\n  @my_syntax %{brace: [{\"***\", %{tag: \"u\"}}]}\n  \n  use Md.Parser, syntax: @my_syntax\n  import Md.Parser.DSL\n\n  comment \"<!--\", %{closing: \"-->\"}\n  ...\nend\n```\n\nInstead of `@syntax` module attribute, one might use\n\n- a parameter to `use Md.Parser` as `use Md.Parser, syntax: map()`\n- a DSL like `paragraph {\"#\", %{tag: :h1}}`.","ref":"Md.html#module-predefined-parsers"},{"type":"function","title":"Md.generate/1","doc":"See  Md.Parser.generate/1 .","ref":"Md.html#generate/1"},{"type":"function","title":"Md.generate/2","doc":"See  Md.Parser.generate/2 .","ref":"Md.html#generate/2"},{"type":"function","title":"Md.generate/3","doc":"See  Md.Parser.generate/3 .","ref":"Md.html#generate/3"},{"type":"function","title":"Md.parse/2","doc":"Interface to the library. Use `parse/2` to parse the input to the state,\nuse `generate/{1,2}` to produce an _HTML_ out of the input.","ref":"Md.html#parse/2"},{"type":"function","title":"Examples - Md.parse/2","doc":"iex> Md.parse(\"   foo\")\n    %Md.Parser.State{ast: [{:p, nil, [\"foo\"]}], mode: [:finished]}\n\n    iex> Regex.replace(~r/\\s+/, Md.generate(\"*bold*\"), \"\")\n    \"  bold  \"\n\n    iex> Md.generate(\"It’s all *bold* and _italic_!\", Md.Parser.Default, format: :none)\n    \" It’s all  bold  and  italic ! \"","ref":"Md.html#parse/2-examples"},{"type":"function","title":"Md.with/1","doc":"Helper function to supply a custom parser in call to `Md.parse/2` as\n\n```elixir\nMd.parse(\"some _text_ with *markup*\", Md.with(Md.Parser.Default))\n```","ref":"Md.html#with/1"},{"type":"module","title":"Md.Guards","doc":"Several guards for the proper UTF8 handling of input.","ref":"Md.Guards.html"},{"type":"module","title":"Examples - Md.Guards","doc":"iex> import Md.Guards\n    iex> with < > <- \" \", do: is_ascii_space(x)\n    true\n    iex> with < > <- \" \", do: is_non_ascii_space(x)\n    false\n    iex> with < > <- \" \", do: is_utf8_space(x)\n    true\n    iex> with < > <- \"!\", do: is_ascii_punct(x)\n    true\n    iex> with < > <- \"!\", do: is_non_ascii_punct(x)\n    false\n    iex> with < > <- \"!\", do: is_utf8_punct(x)\n    true\n    iex> with < > <- \"1\", do: is_ascii_digit(x)\n    true\n    iex> with < > <- \"1\", do: is_non_ascii_digit(x)\n    false\n    iex> with < > <- \"①\", do: is_utf8_digit(x)\n    true","ref":"Md.Guards.html#module-examples"},{"type":"macro","title":"Md.Guards.is_ascii_digit/1","doc":"","ref":"Md.Guards.html#is_ascii_digit/1"},{"type":"macro","title":"Md.Guards.is_ascii_punct/1","doc":"","ref":"Md.Guards.html#is_ascii_punct/1"},{"type":"macro","title":"Md.Guards.is_ascii_space/1","doc":"","ref":"Md.Guards.html#is_ascii_space/1"},{"type":"macro","title":"Md.Guards.is_non_ascii_digit/1","doc":"","ref":"Md.Guards.html#is_non_ascii_digit/1"},{"type":"macro","title":"Md.Guards.is_non_ascii_punct/1","doc":"","ref":"Md.Guards.html#is_non_ascii_punct/1"},{"type":"macro","title":"Md.Guards.is_non_ascii_space/1","doc":"","ref":"Md.Guards.html#is_non_ascii_space/1"},{"type":"macro","title":"Md.Guards.is_utf8_digit/1","doc":"","ref":"Md.Guards.html#is_utf8_digit/1"},{"type":"macro","title":"Md.Guards.is_utf8_punct/1","doc":"","ref":"Md.Guards.html#is_utf8_punct/1"},{"type":"macro","title":"Md.Guards.is_utf8_space/1","doc":"","ref":"Md.Guards.html#is_utf8_space/1"},{"type":"behaviour","title":"Md.Listener","doc":"The listener behaviour to attach to the parser to receive callbacks\nwhen the elements are encountered and processed.","ref":"Md.Listener.html"},{"type":"type","title":"Md.Listener.attributes/0","doc":"","ref":"Md.Listener.html#t:attributes/0"},{"type":"type","title":"Md.Listener.branch/0","doc":"","ref":"Md.Listener.html#t:branch/0"},{"type":"type","title":"Md.Listener.callback/0","doc":"","ref":"Md.Listener.html#t:callback/0"},{"type":"type","title":"Md.Listener.context/0","doc":"","ref":"Md.Listener.html#t:context/0"},{"type":"type","title":"Md.Listener.element/0","doc":"","ref":"Md.Listener.html#t:element/0"},{"type":"callback","title":"Md.Listener.element/2","doc":"","ref":"Md.Listener.html#c:element/2"},{"type":"type","title":"Md.Listener.leaf/0","doc":"","ref":"Md.Listener.html#t:leaf/0"},{"type":"type","title":"Md.Listener.parse_mode/0","doc":"","ref":"Md.Listener.html#t:parse_mode/0"},{"type":"type","title":"Md.Listener.state/0","doc":"","ref":"Md.Listener.html#t:state/0"},{"type":"type","title":"Md.Listener.trace/0","doc":"","ref":"Md.Listener.html#t:trace/0"},{"type":"behaviour","title":"Md.Parser","doc":"Interface to implement for the custopm parsers.\n\nCustom parsers might be used in syntax declaration when the generic functionality\nis not enough.\n\nLet’s consider one needs a specific handling of links with titles.\n\nThe generic engine does not support it, so one would need to implement a custom parser\nand instruct `Md.Parser` to use it with:\n\n```elixir\n# config/prod.exs\n\nconfig :md, syntax: %{\n  custom: [\n    {\"![\", {MyApp.Parsers.Img, %{}}},\n    ...\n  ]\n}\n```\n\nOnce the original parser would meet the `\"![\"` binary, it’d call `MyApp.Parsers.Img.parse/2`.\nThe latter must proceed until the tag is closed and return the remainder and the updated state\nas a tuple.\n\nCustom parsers implementation examples might be found [here](https://github.com/am-kantox/md/tree/master/examples).","ref":"Md.Parser.html"},{"type":"function","title":"Md.Parser.generate/2","doc":"The main function transforming the MD input to XML output.\n\n`options` are passed to `XmlBuilder.generate/2` as is, save for\n  the special two special options, `parser:` and `walker:`.\n\n`parser:` option which is a module implementing `Parser` behaviour,\n  is telling what parser to use for parsing.\n\n`walker:` option which might be a function of arity 2,\n  or a tuple `{:pre | :post, fun}` where `fun` is a function of arity 1 or 2.\n\nIf passed, `XmlBuilder.{pre,post}walk/{2,3}` is being called before generation.\n\nIf `walker:` was not passed, or a `nil` value was returned from the accumulator,\n  this function returns the binary `XML` as is, otherwise it returns a tuple\n  `{XML, accumulator}` where `accumulator` is what has been returned from\n  underlying calls to `XmlBuilder.traverse/4`.","ref":"Md.Parser.html#generate/2"},{"type":"function","title":"Md.Parser.generate/3","doc":"","ref":"Md.Parser.html#generate/3"},{"type":"callback","title":"Md.Parser.parse/2","doc":"Takes a not parsed yet input and the state, returns the updated remainder and state.","ref":"Md.Parser.html#c:parse/2"},{"type":"type","title":"Md.Parser.parsing_stage/0","doc":"The type to be used in all the intermediate states of parsing.\n\nThe first element iof the tuple is the continuation (not parsed yet input,)\nand the latter is the current state.","ref":"Md.Parser.html#t:parsing_stage/0"},{"type":"behaviour","title":"Md.Transforms","doc":"Custom transforms behaviour to be implemented by custom handlers","ref":"Md.Transforms.html"},{"type":"callback","title":"Md.Transforms.apply/2","doc":"Receives the markdown tag and the rest and applies the desired transformation","ref":"Md.Transforms.html#c:apply/2"},{"type":"module","title":"Md.Parser.Default","doc":"Default parser with all the features included.\n\nSupports a wide subset of markdown, including but not limited to:\n\n- bold/italic/strikeout/etc text decorations\n- comments\n- code blocks\n- tables\n- twitter handlers etc\n\nMight be a good start for those who just needs a fast markdown processing.","ref":"Md.Parser.Default.html"},{"type":"function","title":"Md.Parser.Default.listener/2","doc":"","ref":"Md.Parser.Default.html#listener/2"},{"type":"function","title":"Md.Parser.Default.syntax/0","doc":"","ref":"Md.Parser.Default.html#syntax/0"},{"type":"module","title":"Md.Parser.State","doc":"The internal state of the parser.","ref":"Md.Parser.State.html"},{"type":"type","title":"Md.Parser.State.t/0","doc":"","ref":"Md.Parser.State.html#t:t/0"},{"type":"behaviour","title":"Md.Parser.Syntax","doc":"The behaviour for the custom syntax suppliers","ref":"Md.Parser.Syntax.html"},{"type":"type","title":"Md.Parser.Syntax.item/0","doc":"Syntax item definition","ref":"Md.Parser.Syntax.html#t:item/0"},{"type":"function","title":"Md.Parser.Syntax.merge/2","doc":"","ref":"Md.Parser.Syntax.html#merge/2"},{"type":"callback","title":"Md.Parser.Syntax.settings/0","doc":"The implementation should return settings for this particular syntax definition","ref":"Md.Parser.Syntax.html#c:settings/0"},{"type":"type","title":"Md.Parser.Syntax.settings/0","doc":"Settings for the parser","ref":"Md.Parser.Syntax.html#t:settings/0"},{"type":"callback","title":"Md.Parser.Syntax.syntax/0","doc":"The implementation should return a syntax definition","ref":"Md.Parser.Syntax.html#c:syntax/0"},{"type":"type","title":"Md.Parser.Syntax.t/0","doc":"Syntax definition","ref":"Md.Parser.Syntax.html#t:t/0"},{"type":"module","title":"Md.Parser.Syntax.Void","doc":"Void syntax to be extended by custom implementations. Included for convenience.","ref":"Md.Parser.Syntax.Void.html"},{"type":"function","title":"Md.Parser.Syntax.Void.settings/0","doc":"Returns default values for outer tag, span tag and empty tags.","ref":"Md.Parser.Syntax.Void.html#settings/0"},{"type":"function","title":"Md.Parser.Syntax.Void.syntax/0","doc":"Empty syntax","ref":"Md.Parser.Syntax.Void.html#syntax/0"},{"type":"module","title":"Md.Transforms.Anchor","doc":"Anchor transformation to image or twitter card","ref":"Md.Transforms.Anchor.html"},{"type":"module","title":"Md.Transforms.Footnote","doc":"Internal transformation to format footnotes","ref":"Md.Transforms.Footnote.html"},{"type":"module","title":"Md.Transforms.Soundcloud","doc":"Internal transformation to embed soundcloud audios","ref":"Md.Transforms.Soundcloud.html"},{"type":"module","title":"Md.Transforms.TwitterHandle","doc":"Internal transformation to format twitter handles","ref":"Md.Transforms.TwitterHandle.html"},{"type":"module","title":"Md.Transforms.Youtube","doc":"Internal transformation to embed youtube videos","ref":"Md.Transforms.Youtube.html"},{"type":"extras","title":"Md","doc":"# Md ![Md Logo](https://github.com/am-kantox/md/raw/master/stuff/logo-48x48.png) [![Kantox ❤ OSS](https://img.shields.io/badge/❤-kantox_oss-informational.svg)](https://kantox.com/)  ![Test](https://github.com/am-kantox/md/workflows/Test/badge.svg)  ![Dialyzer](https://github.com/am-kantox/md/workflows/Dialyzer/badge.svg)\n\n**Stream markup parser, extendable, flexible, blazingly fast, with callbacks and more, ready for markdown…**\n\n---","ref":"readme.html"},{"type":"extras","title":"Main Focus - Md","doc":"This library is not yet another markdown parser, rather it’s a highly configurable\nand extendable parser for any custom markdown-like markup. It has been created\nmostly to allow custom markdown syntax, like `^foo^` for superscript, or `⇓bar⇓`\nfor subscript. It also supports [custom parsers](https://hexdocs.pm/md/Md.Parser.html)\nfor anything that cannot be handled with generic parsers, inspired by markdown\n(something more complex than standard markdown provides.)\n\nThe library provides callbacks for all the default syntax handlers, as well as for\ncustom handlers, allowing the on-fly modification of what’s currently being processed.\n\n`Md` parses the incoming stream **once** and keeps the state, producing an AST\nof the input document. It has an ability to recover from errors collecting them.\n\nIt currently does not support (and I frankly doubt it ever will)\nlists with embedded quotes, and other contrived syntax. If one needs to perfectly\nparse the common markdown, `Md` is probably not the correct choice.\n\nBut if one wants to easily extend syntax almost without limits, `Md` might be good.","ref":"readme.html#main-focus"},{"type":"extras","title":"Markup Handling - Md","doc":"There are several different syntax patterns recognizable by `Md`. Those are:\n\n- `custom` — the custom parser implementing `Md.Parser` behavious would be called\n- `attributes` — inplace attributes for all tags `\"{{foo:'bar'}}\"` → `\"<… foo='bar' …>\"`\n- `substitute` — simple substitution, like `\"<\"` → `\"&lt;\"`\n- `escape` — characters to be treated as is, not as a part of syntax\n- `comment` — characters to be treated as a comment, discarded in the output\n- `flush` — somewhat breaking a paragraph flow, like triple-dash\n- `magnet` — the markup for a single work following the patters, like `#tag`\n- `block` — the whole block of input treated distinguished, like triple-backtick\n- `shift` — the same as `block`, but the opening marker should precede each line\n  and `\"\\n\"` is treated as the closing marker\n- `pair` — the opening marker followed by closing marker, and a subsequent pair\n  of opening and closing, like `![name](#anchor)`; the second element might\n  be an internal shortcut to the deferred disclosure\n- `disclosure` — the disclosure of elements previously declared as `pair` with\n  `deferred` parameter provided\n- `paragraph` — a header, blockquote, or such, followed by a paragraph flow break\n- `list` — a list, like `- one\\n- two`\n- `tag` — allowed tags (e. g. ` 2 `)\n- `brace` — a most common markdown feature, like text decoration or such (e. g. `**bold**`)","ref":"readme.html#markup-handling"},{"type":"extras","title":"Syntax description - Md","doc":"The syntax must be configured at compile time (because `parse/2` handlers are\ngenerated in compile time.) It is a map, having `settings` key\n\n```elixir\nsettings: %{\n  outer: :p,\n  span: :span,\n  empty_tags: ~w|img hr br|a\n}\n```\n\nand `key ⇒ list_of_tuples` key-values, providing a text markup representation\nand its handling rules. Here is the excerpt from the default parser for `brace`s\n\n```elixir\n  brace: %{\n    \"*\" => %{tag: :b},\n    \"_\" => %{tag: :i},\n    \"**\" => %{tag: :strong, attributes: %{class: \"nota-bene\"}},\n    \"__\" => %{tag: :em},\n    \"~\" => %{tag: :s},\n    \"~~\" => %{tag: :del},\n    \"`\" => %{tag: :code, mode: :raw, attributes: %{class: \"code-inline\"}}\n  }\n```\n\nFor more examples of what properties are allowed for each kind of handlers,\nsee the sources (ATM.)","ref":"readme.html#syntax-description"},{"type":"extras","title":"Predefined parsers - Md","doc":"`Md` comes with a generic predefined parser `Md.Parser.Default`, which includes\nall the markup currently supported by `Md`.\n\nCustom parser definition would be usually based on `Md.Parser.Syntax.Void` syntax\nas shown below\n\n```elixir\ndefmodule MyParser do\n  use Md.Parser\n\n  alias Md.Parser.Syntax.Void\n\n  @default_syntax Map.put(Void.syntax(), :settings, Void.settings())\n  @syntax @default_syntax |> Map.merge(%{\n    comment: [{\"<!--\", %{closing: \"-->\"}}],\n    paragraph: [\n      {\"##\", %{tag: :h2}},\n      {\"###\", %{tag: :h3}},\n      {\">\", %{tag: :blockquote}}\n    ],\n    list:\n      [\n        {\"- \", %{tag: :li, outer: :ul}},\n        {\"+ \", %{tag: :li, outer: :ol}}\n      ]\n    brace: [\n      {\"*\", %{tag: :b}},\n      {\"_\", %{tag: :i}},\n      {\"~\", %{tag: :s}},\n      {\"`\", %{tag: :code, mode: :raw, attributes: %{class: \"code-inline\"}}}\n    ]\n  })\nend\n```\n\n`@syntax` module attribute must be declared, or DSL used as shown below\n(declarations), or an argument in a call to `use Md.Parser`.\nThe separate declarations will be collected and merged.\n\n```elixir\ndefmodule MyDSLParser do\n  @my_syntax %{brace: [{\"***\", %{tag: \"u\"}}]}\n  \n  use Md.Parser, syntax: @my_syntax\n  import Md.Parser.DSL\n\n  comment \"<!--\", %{closing: \"-->\"}\n  ...\nend\n```\n\nInstead of `@syntax` module attribute, one might use\n\n- a parameter to `use Md.Parser` as `use Md.Parser, syntax: map()`\n- a DSL like `paragraph {\"#\", %{tag: :h1}}`.\n\n---","ref":"readme.html#predefined-parsers"},{"type":"extras","title":"Changelog - Md","doc":"- **`0.10.4`** fix pairs with special symbols inside\n- **`0.10.2`** spaces as delimiters in attributes\n- **`0.10.1`** support for the flaky `floki` update\n- **`0.10.0`** [:tag:] attributes for tags\n- **`0.9.10`** [:ant:] escape in blocks (credits @adriansalamon,) sup, sub, center, youtube\n- **`0.9.9`** [:ant:] fixed nested mixed lists\n- **`0.9.7`** [:ant:] fixed custom parsers invocation\n- **`0.9.4`** adds `class: \"empty-anchor\"` to tags expecting attributes to be set, fixed :ant: with nested brackets\n- **`0.9.3`** adds `class: \"empty-tag\"` to empty tags to allow their display supression\n- **`0.9.2`** nested tags shallow support, default support for ` `\n- **`0.9.1`** accept `config :md, :httpc_options` config used with `Floki` in TwitterCard/OG retrieval\n- **`0.9.0`** use `unicode_set` instead of `string_naming` by default for guards\n- **`0.8.5`** advanced `terminators:` in `magnet`\n- **`0.8.4`** `Md.Parser.Syntax.merge/2`\n- **`0.8.2`** `walker:` and `parser:` options in a call to `generate/2`\n- **`0.8.0`** `Md.Transforms.Anchor` supporting twitter/og cards via `Floki`\n- **`0.7.4`** configurable linebreaks (defaults: `\\n`, `\\r\\n`)\n- **`0.7.1`** `Md.Guards` through `StringNaming`\n- **`0.7.0`** allow `payload` to be passed through within state\n- **`0.6.8`** `xml_builder`→`xml_builder_ex` (default formatting for code is now `:none`)\n- **`0.6.0`** allow HTML tags (without attributes yet)\n- **`0.5.0`** DSL + `use Md.Parser, syntax: …`  for configurable syntax\n- **`0.4.0`** configurable syntax as `@syntax`\n- **`0.3.0`** relaxed support for comments and tables\n- **`0.2.1`** deferred references like in `[link][1]` followed by `[1]: https://example.com` somewhere\n- **`0.2.0`** PoC, most of reasonable markdown is supported","ref":"readme.html#changelog"},{"type":"extras","title":"Installation - Md","doc":"```elixir\ndef deps do\n  [\n    {:md, \"~> 0.1\"}\n  ]\nend\n```\n\n### [Documentation](https://hexdocs.pm/md)","ref":"readme.html#installation"},{"type":"extras","title":"Custom Markdown Pipelines","doc":"# Custom Markdown Pipelines\n\nLooking for a flexible, extensible, and blazingly fast markup processor that goes beyond standard markdown? Meet `md`, a highly customizable markup processing library that lets you define your own markup syntax and transformation rules.","ref":"md-benefits.html"},{"type":"extras","title":"Not Just Another Markdown Parser - Custom Markdown Pipelines","doc":"Unlike traditional markdown parsers that offer a fixed set of features, `md` is designed as a toolkit for building custom markup processing pipelines. Think of it as LEGO® for text processing - you get the basic building blocks and the freedom to assemble them however you want.","ref":"md-benefits.html#not-just-another-markdown-parser"},{"type":"extras","title":"Key Features - Custom Markdown Pipelines","doc":"### 🔧 Fully Customizable Syntax\n\n- Define your own markup patterns\n- Support for custom tags and attributes\n- Extensible parser behavior\n- Build your own DSL for specific needs\n\n### 🚀 Stream-Aware Processing\n\n- Process content in a single pass\n- Maintains state throughout parsing\n- Efficient memory usage for large documents\n- Error recovery capabilities\n\n### 🧩 Transform Pipeline\n\nBuilt-in transforms that you can mix and match:\n- Twitter Cards and OpenGraph data extraction\n- YouTube video embedding\n- SoundCloud track embedding\n- Twitter handle linking\n- Footnote processing\n- And more!\n\n### ⚡ Performance First\n\n- Single-pass parsing\n- Stream-based processing\n- Minimal memory footprint\n- No unnecessary reparsing","ref":"md-benefits.html#key-features"},{"type":"extras","title":"Use Cases - Custom Markdown Pipelines","doc":"Perfect for:\n- Custom documentation systems\n- Domain-specific markup languages\n- Content management systems\n- Social media content processing\n- Technical documentation with custom needs","ref":"md-benefits.html#use-cases"},{"type":"extras","title":"Example: Custom Syntax - Custom Markdown Pipelines","doc":"```elixir\ndefmodule MyParser do\n  use Md.Parser\n\n  # Define your own syntax patterns\n  @syntax %{\n    comment: [{\"<!--\", %{closing: \"-->\"}}],\n    paragraph: [\n      {\"##\", %{tag: :h2}},\n      {\"###\", %{tag: :h3}},\n      {\">\", %{tag: :blockquote}}\n    ],\n    list: [\n      {\"- \", %{tag: :li, outer: :ul}},\n      {\"+ \", %{tag: :li, outer: :ol}}\n    ],\n    brace: [\n      {\"*\", %{tag: :b}},\n      {\"_\", %{tag: :i}},\n      {\"~\", %{tag: :s}},\n      {\"`\", %{tag: :code, mode: :raw}}\n    ]\n  }\nend\n```","ref":"md-benefits.html#example-custom-syntax"},{"type":"extras","title":"Using the DSL Syntax - Custom Markdown Pipelines","doc":"In addition to defining syntax using maps, `md` provides a declarative DSL for defining your markup rules:\n\n```elixir\ndefmodule MyDSLParser do\n  use Md.Parser, dsl: true\n  \n  # Basic markup elements\n  brace \"*\", %{tag: :strong}\n  brace \"_\", %{tag: :em}\n  brace \"`\", %{tag: :code, mode: :raw}\n  \n  # Headers and paragraphs\n  paragraph \"#\", %{tag: :h1}\n  paragraph \"##\", %{tag: :h2}\n  paragraph \">\", %{tag: :blockquote}\n  \n  # Lists\n  list \"- \", %{tag: :li, outer: :ul}\n  list \"* \", %{tag: :li, outer: :ul}\n  list \"1. \", %{tag: :li, outer: :ol}\n  \n  # Custom elements\n  magnet \"#\", %{tag: :span, class: \"hashtag\"}\n  magnet \"@\", %{tag: :a, href: \"https://twitter.com/{{text}}\"}\n  \n  # Special blocks\n  block \"```\", %{tag: :pre, class: \"code\"}\n  block \"~~~\", %{tag: :div, class: \"quote\"}\n  \n  # Comments\n  comment \"<!--\", %{closing: \"-->\"}\n  \n  # Parser settings\n  outer :article\n  span :span\n  empty_tags ~w|br hr img|a\n  linebreaks ~w|\\n \\r\\n|\nend\n```\n\nThe DSL supports all markdown element types:\n- `:custom` - Custom parsers for special syntax\n- `:attributes` - Inline attribute definitions\n- `:substitute` - Simple text substitutions\n- `:escape` - Characters to be escaped\n- `:comment` - Comment syntax\n- `:matrix` - Table and matrix syntax\n- `:flush` - Paragraph break markers\n- `:magnet` - Single-word markers like #tags\n- `:block` - Multi-line blocks\n- `:shift` - Indentation-based blocks\n- `:pair` - Opening/closing pairs\n- `:disclosure` - Reference declarations\n- `:paragraph` - Block-level elements\n- `:list` - List item markers\n- `:tag` - HTML tag handling\n- `:brace` - Inline markup\n\nParser settings can be configured with:\n- `outer` - Default outer container tag\n- `span` - Default inline container tag\n- `linebreaks` - Line break characters\n- `disclosure_range` - Range for reference numbering\n- `empty_tags` - Tags that don’t need closing\n- `requiring_attributes_tags` - Tags that must have attributes\n- `linewrap` - Enable/disable line wrapping","ref":"md-benefits.html#using-the-dsl-syntax"},{"type":"extras","title":"Transform Pipeline Example - Custom Markdown Pipelines","doc":"```elixir\n# Basic parsing with default settings\ncontent\n|> Md.generate(Md.Parser.Default)\n\n# With custom parser and formatting options\ncontent\n|> Md.generate(MyParser, format: :none)\n```","ref":"md-benefits.html#transform-pipeline-example"},{"type":"extras","title":"When to Use Md - Custom Markdown Pipelines","doc":"Choose `md` when you need:\n- Custom markup syntax beyond standard markdown\n- Flexible processing pipeline\n- High-performance text processing\n- Stream-based content handling\n- Error recovery capabilities\n\nDon’t choose `md` when you:\n- Need a drop-in markdown parser\n- Want 100% CommonMark compatibility\n- Don’t require custom syntax or transforms","ref":"md-benefits.html#when-to-use-md"},{"type":"extras","title":"Getting Started - Custom Markdown Pipelines","doc":"Add to your mix.exs:\n\n```elixir\ndef deps do\n  [{:md, \"~> 0.10\"}]\nend\n```","ref":"md-benefits.html#getting-started"},{"type":"extras","title":"Learn More - Custom Markdown Pipelines","doc":"Check out the [documentation](https://hexdocs.pm/md) for detailed examples and API reference.\n\n---\n\n`md` isn’t trying to be another markdown parser—it’s a toolkit for building your own markup processing pipeline. If you need flexibility, performance, and custom syntax support, give it a try!","ref":"md-benefits.html#learn-more"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.38.2"}}